pub struct Script(/* private fields */);
A Bitcoin script

Implementations



impl Script

pub fn new() -> Script

Creates a new empty script

pub fn len(&self) -> usize

The length in bytes of the script

pub fn is_empty(&self) -> bool

Whether the script is the empty script

pub fn as_bytes(&self) -> &[u8]

Returns the script data

pub fn to_bytes(&self) -> Vec<u8>

Returns a copy of the script data

pub fn into_bytes(self) -> Vec<u8>

Convert the script into a byte vector

pub fn to_p2sh(&self) -> Script

Compute the P2SH output corresponding to this redeem script

pub fn to_v0_p2wsh(&self) -> Script

Compute the P2WSH output corresponding to this witnessScript (aka the “witness redeem script”)

pub fn is_p2sh(&self) -> bool

Checks whether a script pubkey is a p2sh output

pub fn is_p2pkh(&self) -> bool

Checks whether a script pubkey is a p2pkh output

pub fn is_p2pk(&self) -> bool

Checks whether a script pubkey is a p2pkh output

pub fn is_v0_p2wsh(&self) -> bool

Checks whether a script pubkey is a p2wsh output

pub fn is_v0_p2wpkh(&self) -> bool

Checks whether a script pubkey is a p2wpkh output

pub fn is_op_return(&self) -> bool

Check if this is an OP_RETURN output

pub fn is_provably_unspendable(&self) -> bool

Whether a script can be proven to have no satisfying input

pub fn iter(&self, enforce_minimal: bool) -> Instructions<'_>

Iterate over the script in the form of Instructions, which are an enum covering opcodes, datapushes and errors. At most one error will be returned and then the iterator will end. To instead iterate over the script as sequence of bytes, treat it as a slice using script[..] or convert it to a vector using into_bytes().