pub enum FunctionType {
    Variadic(TypeSignature, TypeSignature),
    Fixed(FixedFunction),
    UnionArgs(Vec<TypeSignature>, TypeSignature),
    ArithmeticVariadic,
    ArithmeticUnary,
    ArithmeticBinary,
    ArithmeticComparison,
    Binary(FunctionArgSignature, FunctionArgSignature, FunctionReturnsSignature),
}

Variants



Variadic(TypeSignature, TypeSignature)



Fixed(FixedFunction)



UnionArgs(Vec<TypeSignature>, TypeSignature)



ArithmeticVariadic



ArithmeticUnary



ArithmeticBinary



ArithmeticComparison



Binary(FunctionArgSignature, FunctionArgSignature, FunctionReturnsSignature)

Implementations

source

impl FunctionType

source

impl FunctionType

source

pub fn check_args_2_05<T>( &self, accounting: &mut T, args: &[TypeSignature] ) -> Result<TypeSignature, CheckError>where T: CostTracker,

source

pub fn check_args_by_allowing_trait_cast_2_05( &self, db: &mut AnalysisDatabase<'_>, func_args: &[Value] ) -> Result<TypeSignature, CheckError>

source

impl FunctionType

source

pub fn check_args_2_1<T>( &self, accounting: &mut T, args: &[TypeSignature], clarity_version: ClarityVersion ) -> Result<TypeSignature, CheckError>where T: CostTracker,

source

pub fn principal_to_callable_type( &self, value: &Value, depth: u8, clarity_version: ClarityVersion ) -> Result<TypeSignature, CheckError>

Returns the type of value, after converting any contract principal types to callable types. In an initial transaction, arguments are typed as contract principals, but they must be principal literals, so they may be used to call into a contract.

source

pub fn check_args_by_allowing_trait_cast_2_1( &self, db: &mut AnalysisDatabase<'_>, clarity_version: ClarityVersion, func_args: &[Value] ) -> Result<TypeSignature, CheckError>

This method is only used by StacksChainState::can_include_tx. The cost of evaluating these type checks are not tracked. WARNING: This is not consensus-critical code, and should never be called from consensus-critical code.

source

impl FunctionType

source

pub fn check_args<T>( &self, accounting: &mut T, args: &[TypeSignature], epoch: StacksEpochId, clarity_version: ClarityVersion ) -> Result<TypeSignature, CheckError>where T: CostTracker,

source

pub fn check_args_by_allowing_trait_cast( &self, db: &mut AnalysisDatabase<'_>, func_args: &[Value], epoch: StacksEpochId, clarity_version: ClarityVersion ) -> Result<TypeSignature, CheckError>