Struct clarity_repl::clarity::vm::types::StringUTF8Length
source · pub struct StringUTF8Length(/* private fields */);Trait Implementations
sourceimpl Clone for StringUTF8Length
impl Clone for StringUTF8Length
sourcefn clone(&self) -> StringUTF8Length
fn clone(&self) -> StringUTF8Length
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for StringUTF8Length
impl Debug for StringUTF8Length
sourceimpl<'de> Deserialize<'de> for StringUTF8Length
impl<'de> Deserialize<'de> for StringUTF8Length
sourcefn deserialize<__D>(
__deserializer: __D
) -> Result<StringUTF8Length, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>( __deserializer: __D ) -> Result<StringUTF8Length, <__D as Deserializer<'de>>::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Display for StringUTF8Length
impl Display for StringUTF8Length
sourceimpl PartialEq for StringUTF8Length
impl PartialEq for StringUTF8Length
sourcefn eq(&self, other: &StringUTF8Length) -> bool
fn eq(&self, other: &StringUTF8Length) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for StringUTF8Length
impl Serialize for StringUTF8Length
sourcefn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>( &self, __serializer: __S ) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where __S: Serializer,
Serialize this value into the given Serde serializer. Read more
sourceimpl TryFrom<i128> for StringUTF8Length
impl TryFrom<i128> for StringUTF8Length
type Error = CheckErrors
type Error = CheckErrors
The type returned in the event of a conversion error.
sourcefn try_from(data: i128) -> Result<StringUTF8Length, CheckErrors>
fn try_from(data: i128) -> Result<StringUTF8Length, CheckErrors>
Performs the conversion.
sourceimpl TryFrom<u32> for StringUTF8Length
impl TryFrom<u32> for StringUTF8Length
type Error = CheckErrors
type Error = CheckErrors
The type returned in the event of a conversion error.
sourcefn try_from(data: u32) -> Result<StringUTF8Length, CheckErrors>
fn try_from(data: u32) -> Result<StringUTF8Length, CheckErrors>
Performs the conversion.
sourceimpl TryFrom<usize> for StringUTF8Length
impl TryFrom<usize> for StringUTF8Length
type Error = CheckErrors
type Error = CheckErrors
The type returned in the event of a conversion error.
sourcefn try_from(data: usize) -> Result<StringUTF8Length, CheckErrors>
fn try_from(data: usize) -> Result<StringUTF8Length, CheckErrors>
Performs the conversion.
impl Eq for StringUTF8Length
impl StructuralEq for StringUTF8Length
impl StructuralPartialEq for StringUTF8Length