#[repr(u8)]pub enum TransactionAuthFieldID {
PublicKeyCompressed = 0,
PublicKeyUncompressed = 1,
SignatureCompressed = 2,
SignatureUncompressed = 3,
}Expand description
Transaction signatures are validated by calculating the public key from the signature, and verifying that all public keys hash to the signing account’s hash. To do so, we must preserve enough information in the auth structure to recover each public key’s bytes.
An auth field can be a public key or a signature. In both cases, the public key (either given in-the-raw or embedded in a signature) may be encoded as compressed or uncompressed.
Variants
PublicKeyCompressed = 0
PublicKeyUncompressed = 1
SignatureCompressed = 2
SignatureUncompressed = 3