Struct clarity_repl::codec::CoinbasePayload
source · pub struct CoinbasePayload(pub [u8; 32]);Expand description
A coinbase commits to 32 bytes of control-plane information
Tuple Fields
0: [u8; 32]Implementations
sourceimpl CoinbasePayload
impl CoinbasePayload
sourceimpl CoinbasePayload
impl CoinbasePayload
sourcepub fn from_hex(hex_str: &str) -> Result<CoinbasePayload, HexError>
pub fn from_hex(hex_str: &str) -> Result<CoinbasePayload, HexError>
Instantiates from a hex string
sourcepub fn from_bytes(inp: &[u8]) -> Option<CoinbasePayload>
pub fn from_bytes(inp: &[u8]) -> Option<CoinbasePayload>
Instantiates from a slice of bytes
sourcepub fn from_bytes_be(inp: &[u8]) -> Option<CoinbasePayload>
pub fn from_bytes_be(inp: &[u8]) -> Option<CoinbasePayload>
Instantiates from a slice of bytes, converting to host byte order
sourcepub fn from_vec_be(b: &Vec<u8>) -> Option<CoinbasePayload>
pub fn from_vec_be(b: &Vec<u8>) -> Option<CoinbasePayload>
Instantiates from a big-endian vector of bytes, converting to host byte order