pub struct MinerReward {
    pub address: StacksAddress,
    pub recipient: PrincipalData,
    pub coinbase: u128,
    pub tx_fees_anchored: u128,
    pub tx_fees_streamed_produced: u128,
    pub tx_fees_streamed_confirmed: u128,
    pub vtxindex: u32,
}
A record of a coin reward for a miner. There will be at most two of these for a miner: one for the coinbase + block-txs + confirmed-mblock-txs, and one for the produced-mblock-txs. The latter reward only stores the produced-mblock-txs, and is only ever stored if the microblocks are ever confirmed.

Fields

address: StacksAddress

address of the miner that produced the block

recipient: PrincipalData

address of the entity that receives the block reward. Ignored pre-2.1

coinbase: u128

block coinbase

tx_fees_anchored: u128

block transaction fees

tx_fees_streamed_produced: u128

microblock transaction fees from transactions mined by this miner

tx_fees_streamed_confirmed: u128

microblock transaction fees from transactions confirmed by this miner

vtxindex: u32

virtual transaction index in the block where these rewards get applied. the miner’s reward is applied first (so vtxindex == 0) and user-burn supports would be applied after (so vtxindex > 0).