pub struct MultisigSpendingCondition {
    pub hash_mode: MultisigHashMode,
    pub signer: Hash160,
    pub nonce: u64,
    pub tx_fee: u64,
    pub fields: Vec<TransactionAuthField>,
    pub signatures_required: u16,
}
A structure that encodes enough state to authenticate a transaction’s execution against a Stacks address. public_keys + signatures_required determines the Principal. nonce is the “check number” for the Principal.

Fields

hash_mode: MultisigHashModesigner: Hash160nonce: u64tx_fee: u64fields: Vec<TransactionAuthField>signatures_required: u16

Implementations

source

impl MultisigSpendingCondition

source

pub fn push_signature( &mut self, key_encoding: TransactionPublicKeyEncoding, signature: MessageSignature )

source

pub fn push_public_key(&mut self, public_key: Secp256k1PublicKey)

source

pub fn pop_auth_field(&mut self) -> Option<TransactionAuthField>

source

pub fn address_mainnet(&self) -> StacksAddress

source

pub fn address_testnet(&self) -> StacksAddress

source

pub fn verify( &self, initial_sighash: &Txid, cond_code: &TransactionAuthFlags ) -> Result<Txid, CodecError>

Authenticate a spending condition against an initial sighash. In doing so, recover all public keys and verify that they hash to the signer via the given hash mode.