Struct clarity_repl::codec::TransactionContractCall
source · pub struct TransactionContractCall {
pub address: StacksAddress,
pub contract_name: ContractName,
pub function_name: ClarityName,
pub function_args: Vec<Value>,
}Expand description
A transaction that calls into a smart contract
Fields
address: StacksAddresscontract_name: ContractNamefunction_name: ClarityNamefunction_args: Vec<Value>Trait Implementations
sourceimpl Clone for TransactionContractCall
impl Clone for TransactionContractCall
sourcefn clone(&self) -> TransactionContractCall
fn clone(&self) -> TransactionContractCall
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TransactionContractCall
impl Debug for TransactionContractCall
sourceimpl<'de> Deserialize<'de> for TransactionContractCall
impl<'de> Deserialize<'de> for TransactionContractCall
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for TransactionContractCall
impl PartialEq for TransactionContractCall
sourcefn eq(&self, other: &TransactionContractCall) -> bool
fn eq(&self, other: &TransactionContractCall) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for TransactionContractCall
impl Serialize for TransactionContractCall
sourceimpl StacksMessageCodec for TransactionContractCall
impl StacksMessageCodec for TransactionContractCall
sourcefn consensus_serialize<W: Write>(&self, fd: &mut W) -> Result<(), CodecError>
fn consensus_serialize<W: Write>(&self, fd: &mut W) -> Result<(), CodecError>
serialize implementors should never error unless there is an underlying
failure in writing to the
fdfn consensus_deserialize<R: Read>( fd: &mut R ) -> Result<TransactionContractCall, CodecError>
impl StructuralPartialEq for TransactionContractCall