Struct clarity_repl::codec::TransactionSmartContract
source · pub struct TransactionSmartContract {
pub name: ContractName,
pub code_body: StacksString,
}Expand description
A transaction that instantiates a smart contract
Fields
name: ContractNamecode_body: StacksStringTrait Implementations
sourceimpl Clone for TransactionSmartContract
impl Clone for TransactionSmartContract
sourcefn clone(&self) -> TransactionSmartContract
fn clone(&self) -> TransactionSmartContract
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TransactionSmartContract
impl Debug for TransactionSmartContract
sourceimpl<'de> Deserialize<'de> for TransactionSmartContract
impl<'de> Deserialize<'de> for TransactionSmartContract
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for TransactionSmartContract
impl PartialEq for TransactionSmartContract
sourcefn eq(&self, other: &TransactionSmartContract) -> bool
fn eq(&self, other: &TransactionSmartContract) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for TransactionSmartContract
impl Serialize for TransactionSmartContract
sourceimpl StacksMessageCodec for TransactionSmartContract
impl StacksMessageCodec for TransactionSmartContract
sourcefn consensus_serialize<W: Write>(&self, fd: &mut W) -> Result<(), CodecError>
fn consensus_serialize<W: Write>(&self, fd: &mut W) -> Result<(), CodecError>
serialize implementors should never error unless there is an underlying
failure in writing to the
fdfn consensus_deserialize<R: Read>( fd: &mut R ) -> Result<TransactionSmartContract, CodecError>
impl StructuralPartialEq for TransactionSmartContract