Struct clarity_repl::codec::MinerReward
source · pub struct MinerReward {
pub address: StacksAddress,
pub recipient: PrincipalData,
pub coinbase: u128,
pub tx_fees_anchored: u128,
pub tx_fees_streamed_produced: u128,
pub tx_fees_streamed_confirmed: u128,
pub vtxindex: u32,
}Expand description
A record of a coin reward for a miner. There will be at most two of these for a miner: one for the coinbase + block-txs + confirmed-mblock-txs, and one for the produced-mblock-txs. The latter reward only stores the produced-mblock-txs, and is only ever stored if the microblocks are ever confirmed.
Fields
address: StacksAddressaddress of the miner that produced the block
recipient: PrincipalDataaddress of the entity that receives the block reward. Ignored pre-2.1
coinbase: u128block coinbase
tx_fees_anchored: u128block transaction fees
tx_fees_streamed_produced: u128microblock transaction fees from transactions mined by this miner
tx_fees_streamed_confirmed: u128microblock transaction fees from transactions confirmed by this miner
vtxindex: u32virtual transaction index in the block where these rewards get applied. the miner’s reward is applied first (so vtxindex == 0) and user-burn supports would be applied after (so vtxindex > 0).