Struct clarity_repl::repl::datastore::Datastore
source · pub struct Datastore { /* private fields */ }Implementations
sourceimpl Datastore
impl Datastore
pub fn open( path_str: &str, miner_tip: Option<&StacksBlockId> ) -> Result<Datastore>
pub fn as_analysis_db(&mut self) -> AnalysisDatabase<'_>
sourcepub fn begin(&mut self, current: &StacksBlockId, next: &StacksBlockId)
pub fn begin(&mut self, current: &StacksBlockId, next: &StacksBlockId)
begin, commit, rollback a save point identified by key this is used to clean up any data from aborted blocks (NOT aborted transactions that is handled by the clarity vm directly). The block header hash is used for identifying savepoints. this cannot be used to rollback to arbitrary prior block hash, because that blockhash would already have committed and no longer exist in the save point stack. this is a “lower-level” rollback than the roll backs performed in ClarityDatabase or AnalysisDatabase – this is done at the backing store level.
pub fn rollback(&mut self)
pub fn commit_mined_block(&mut self, will_move_to: &StacksBlockId)
pub fn commit_to(&mut self, final_bhh: &StacksBlockId)
pub fn get_chain_tip(&self) -> &StacksBlockId
pub fn set_chain_tip(&mut self, bhh: &StacksBlockId)
pub fn put(&mut self, key: &str, value: &str)
pub fn make_contract_hash_key(contract: &QualifiedContractIdentifier) -> String